@@ -14,14 +14,14 @@ use strict;
 sub lngbase {
  my @msg =CGI::Bus::lngbase::CGI_Bus_tm::lngbase;
  push @msg,
- (-lgn=>['',    '  ⥬']
- ,-nap=>['',     '孨 ஢']
+ (-nap=>['',     '孨 ஢']
  ,-nup=>['',     '襫騩 ஢']
  ,-nth=>['',    ' ਫ -㬮砭']
  ,-bck=>['',    '  ।饬 ࠭']
+ ,-lgn=>['',    '  ⥬']
  ,-lst=>['',     '  ᮣ᭮ ᫮ 롮ન (᪠)']
  ,-lsr=>['',     ' ᯨ᮪ ᥩ']
- ,-qry=>['᫮',  '᫮ 롮ન (᪠) ᥩ']
+ ,-qry=>['',   '᫮ 롮ન (᪠) ᥩ']
  ,-crt=>['',  '  , ⮡ ⥬ \'⠢\'    ']
  ,-sel=>['',  '()    ,  ']
  ,-edt=>['',   '४⥫ ᬮ / ।஢ ']
